
.onLoad <- function(libname=NULL, pkgname=prim)
{
  ##cat("prim 1.0.3 (2007)\n")
}
